@@ -21,7 +21,6 @@ from typing import (Any, Callable, DefaultDict, Dict, Generator, List,
                     Optional, Sequence, Set, Tuple, Type, Union)
 
 import numpy as np
-from pydicom import config
 from pydicom.dataset import (Dataset, FileDataset, FileMetaDataset,
                              validate_file_meta)
 from pydicom.filereader import dcmread
@@ -36,9 +35,6 @@ from pydicom.values import convert_numbers
 from .geometry import PointMm, RegionMm, SizeMm
 from .uid import ANN_SOP_CLASS_UID, SlideUids, UID
 
-config.enforce_valid_values = True
-config.future_behavior()
-
 
 @dataclass
 class LabColor:
@@ -1395,7 +1391,7 @@ class AnnotationGroup:
         indices: List[int] = []
         for i, annotation in enumerate(self.annotations):
             indices += [i + 1] * len(annotation.get_measurements(type, unit))
-        return np.array(indices, dtype=int)
+        return np.array(indices, dtype=np.int32)
 
     def _create_measurement_values(
         self,
@@ -1619,7 +1615,7 @@ class AnnotationGroup:
             Dataset containing the group.
         """
         ds = Dataset()
-        ds.AnnotationGroupNumber = group_number + 1
+        ds.AnnotationGroupNumber = group_number
         ds.AnnotationGroupUID = self._uid
         ds.NumberOfAnnotations = len(self.annotations)
         ds.GraphicType = self.annotation_type
@@ -1778,7 +1774,7 @@ class PolylineAnnotationGroupMeta(AnnotationGroup):
         for annotation in self.annotations:
             indices.append(index)
             index += len(annotation.geometry.data)
-        return np.array(indices, dtype=int)
+        return np.array(indices, dtype=np.int32)
 
     @staticmethod
     def _get_indices_from_ds(
