@@ -13,10 +13,9 @@
 #    limitations under the License.
 
 import struct
-import warnings
 from abc import ABCMeta, abstractmethod
 from dataclasses import dataclass
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Sequence
 
 import numpy as np
 from PIL import Image
@@ -325,7 +324,7 @@ class Illumination:
     """Set of illumination conditions for optical path"""
     def __init__(
         self,
-        illumination_method: List[ConceptCode] = [],
+        illumination_method: Sequence[ConceptCode] = [],
         illumination_wavelength: Optional[float] = None,
         illumination_color: Optional[ConceptCode] = None,
         illuminator: Optional[ConceptCode] = None
@@ -457,7 +456,7 @@ class OpticalPath:
         lut: Optional[Lut] = None,
         light_path_filter: Optional[LightPathFilter] = None,
         image_path_filter: Optional[ImagePathFilter] = None,
-        channel_description: Optional[List[ConceptCode]] = None,
+        channel_description: Optional[Sequence[ConceptCode]] = None,
         lenses: Optional[Lenses] = None
     ):
         """Create a OpticalPath from identifier, illumination, photometric
@@ -481,20 +480,12 @@ class OpticalPath:
             Optional light path filter description for the optical path.
         image_path_filter: Optional[ImagePathFilter] = None
             Optional image path filter description for the optical path.
-        channel_description: Optional[List[ConceptCode]] = None
+        channel_description: Optional[Sequence[ConceptCode]] = None
             Optional channel description for the optical path.
         lenses: Optional[Lenses] = None
             Optional lens description for the optical path.
         """
 
-        if photometric_interpretation != 'MONOCHROME2' and icc_profile is None:
-            warnings.warn(
-                "Icc profile required if photometric is "
-                f"{photometric_interpretation}"
-            )
-        if lut is not None and icc_profile is None:
-            warnings.warn("Icc profile required if lut is present")
-
         self.identifier = identifier
         self.illumination = illumination
         self.description = description
@@ -571,13 +562,13 @@ class OpticalManager:
     """Store optical paths loaded from dicom files."""
     def __init__(
         self,
-        optical_paths: List[OpticalPath] = [],
+        optical_paths: Sequence[OpticalPath] = [],
     ):
         """Create a OpticalManager from list of OpticalPaths.
 
         Parameters
         ----------
-        optical_paths: List[OpticalPath] = []
+        optical_paths: Sequence[OpticalPath] = []
             List of OpticalPaths.
         """
         self._optical_paths: Dict[str, OpticalPath] = {
@@ -586,13 +577,13 @@ class OpticalManager:
         }
 
     @classmethod
-    def open(cls, instances: List[WsiInstance]) -> 'OpticalManager':
+    def open(cls, instances: Sequence[WsiInstance]) -> 'OpticalManager':
         """Parse optical path sequence in listed instances and create an
         OpticalManager out of the found (unique) OpticalPaths.
 
         Parameters
         ----------
-        files: List[WsiInstance]
+        files: Sequence[WsiInstance]
             List of WsiDicom instances to parse
 
         Returns
@@ -603,7 +594,9 @@ class OpticalManager:
         optical_paths: Dict[str, OpticalPath] = {}
         for instance in instances:
             for dataset in instance.datasets:
-                optical_path_sequence = dataset.OpticalPathSequence
+                optical_path_sequence = dataset.optical_path_sequence
+                if optical_path_sequence is None:
+                    continue
                 for optical_path in optical_path_sequence:
                     identifier = str(optical_path.OpticalPathIdentifier)
                     if identifier not in optical_paths:
